@@ -19,6 +19,10 @@ from .token import (
     create_wordnet_synonym_augmenter,
     create_token_replace_augmenter,
     create_starting_case_augmenter,
+    create_token_insert_random_augmenter,
+    create_token_insert_augmenter,
+    create_random_synonym_insertion_augmenter,
+    create_duplicate_token_augmenter
 )
 from .span import (
     create_per_replace_augmenter,
@@ -46,4 +50,4 @@ from .lang import (
     create_qwerty_da,
 )
 
-from .augment_utilities import combine, set_doc_level, yield_original
+from .augment_utilities import combine, set_doc_level, yield_original, repeat
